README = {
    "objects": {
        "geo-watch-Cache-Creek-2024-10-06-a": [],
        "geo-watch-Cache-Creek-2x-wider-2024-10-06-a": [],
        "geo-watch-Cache-Creek-2024-11-05": [],
        "geo-watch-Cache-Creek-2x-wider-2024-11-05": [],
    },
    "thumbnail": {
        "scale": 4,
    },
}
