#! /usr/bin/env bash

alias @catalog=blue_geo_catalog
alias @datacube=blue_geo_datacube

alias @gdal=blue_geo_gdal

alias @geo=blue_geo

alias @targets=blue_geo_watch_targets

alias QGIS=blue_geo_QGIS
